@@ -2,8 +2,9 @@ import sys
 import time
 import click
 import jmespath
+from natsort import natsorted, ns
 from cloudscale import Cloudscale, CloudscaleApiException
-from ..util import to_table, to_pretty_json, tags_to_dict
+from ..util import to_table, to_pretty_json, tags_to_dict, format_json
 
 if sys.stdout.isatty():
     from yaspin import yaspin as Spinner
@@ -38,6 +39,12 @@ class CloudscaleCommand:
         # Alternate key to look for the resource as 'name'
         self.resource_name_key = 'name'
 
+        # Some resource have a different identifier name
+        self.resource_uuid_name = 'UUID'
+
+        # Usually we want to sort the table by the key used as name
+        self.resource_table_sort_key = None
+
         self.response_transform_json = None
 
     def get_client_resource(self):
@@ -49,7 +56,16 @@ class CloudscaleCommand:
         else:
             if isinstance(response, dict):
                 response = [response]
-            return to_table(response, self.headers, self.response_transform_json)
+
+            if response:
+                response = format_json(response, self.response_transform_json)
+                sort_by_key = self.resource_table_sort_key or self.resource_name_key
+                if sort_by_key:
+                    if 'zone' in self.headers:
+                        response = natsorted(response, key=lambda x: (x['zone'], x[sort_by_key]), alg=ns.IGNORECASE)
+                    else:
+                        response = natsorted(response, key=lambda x: x[sort_by_key], alg=ns.IGNORECASE)
+            return to_table(response, self.headers)
 
     def cmd_list(self, filter_tag=None, filter_json=None, action=None, delete=False, force=False, wait=False):
         if action and delete:
@@ -116,16 +132,16 @@ class CloudscaleCommand:
 
     def cmd_show(self, uuid):
         try:
-            with Spinner(text=f"Querying by UUID {uuid}"):
+            with Spinner(text=f"Querying by {self.resource_uuid_name} {uuid}"):
                 response = self.get_client_resource().get_by_uuid(uuid)
             click.echo(self._format_output(response))
         except CloudscaleApiException as e:
             results = self.cmd_get_by_name(name=uuid)
             if not results:
                 if self.resource_name_key:
-                    msg = f"No resource found for {self.cloud_resource_name} having UUID or {self.resource_name_key}: {uuid}"
+                    msg = f"No resource found for {self.cloud_resource_name} having {self.resource_uuid_name} or {self.resource_name_key}: {uuid}"
                 else:
-                    msg = f"No resource found for {self.cloud_resource_name} having UUID: {uuid}"
+                    msg = f"No resource found for {self.cloud_resource_name} having {self.resource_uuid_name}: {uuid}"
                 click.echo(msg, err=True)
                 sys.exit(1)
             click.echo(self._format_output(results))
@@ -153,26 +169,26 @@ class CloudscaleCommand:
             click.echo(e, err=True)
             sys.exit(1)
 
-    def cmd_update(self, uuid, tags, clear_tags, clear_all_tags, wait=False, **kwargs):
+    def cmd_update(self, uuid, tags=None, clear_tags=None, clear_all_tags=False, wait=False, **kwargs):
             try:
-                with Spinner(text=f"Querying by UUID {uuid}"):
+                with Spinner(text=f"Querying by {self.resource_uuid_name} {uuid}"):
                     self.get_client_resource().get_by_uuid(uuid)
 
             except CloudscaleApiException as e:
                 results = self.cmd_get_by_name(name=uuid)
                 if not results:
                     if self.resource_name_key:
-                        msg = f"No resource found for {self.cloud_resource_name} having UUID or {self.resource_name_key}: {uuid}"
+                        msg = f"No resource found for {self.cloud_resource_name} having {self.resource_uuid_name} or {self.resource_name_key}: {uuid}"
                     else:
-                        msg = f"No resource found for {self.cloud_resource_name} having UUID: {uuid}"
+                        msg = f"No resource found for {self.cloud_resource_name} having {self.resource_uuid_name}: {uuid}"
                     click.echo(msg, err=True)
                     sys.exit(1)
 
                 if len(results) > 1:
-                    click.echo(f"Error: More than one resource found for {self.cloud_resource_name} having name: {uuid}. Please use UUID to select the resource.", err=True)
+                    click.echo(f"Error: More than one resource found for {self.cloud_resource_name} having name: {uuid}. Please use {self.resource_uuid_name} to select the resource.", err=True)
                     sys.exit(1)
 
-                # Single resource found, remember UUID
+                # Single resource found, remember identifier
                 uuid = results[0]['href'].split('/')[-1]
 
             try:
@@ -195,7 +211,7 @@ class CloudscaleCommand:
                         _tags = None
 
 
-                with Spinner(text=f"Updating by UUID {uuid}"):
+                with Spinner(text=f"Updating by {self.resource_uuid_name} {uuid}"):
                     self.get_client_resource().update(
                         uuid=uuid,
                         tags=_tags,
@@ -217,15 +233,15 @@ class CloudscaleCommand:
         try:
             if not skip_query:
                 try:
-                    with Spinner(text=f"Querying by UUID {uuid}"):
+                    with Spinner(text=f"Querying by {self.resource_uuid_name} {uuid}"):
                         response = self.get_client_resource().get_by_uuid(uuid)
                 except CloudscaleApiException as e:
                     results = self.cmd_get_by_name(name=uuid)
                     if not results:
                         if self.resource_name_key:
-                            msg = f"No resource found for {self.cloud_resource_name} having UUID or {self.resource_name_key}: {uuid}"
+                            msg = f"No resource found for {self.cloud_resource_name} having {self.resource_uuid_name} or {self.resource_name_key}: {uuid}"
                         else:
-                            msg = f"No resource found for {self.cloud_resource_name} having UUID: {uuid}"
+                            msg = f"No resource found for {self.cloud_resource_name} having {self.resource_uuid_name}: {uuid}"
                         click.echo(msg, err=True)
                         sys.exit(1)
 
@@ -233,7 +249,7 @@ class CloudscaleCommand:
                         click.echo(f"Error: More than one resource found for {self.cloud_resource_name} having name: {uuid}", err=True)
                         sys.exit(1)
 
-                    # Single resource found, remember UUID
+                    # Single resource found, remember identifier
                     response = results[0]
                     uuid = results[0]['href'].split('/')[-1]
 
@@ -241,7 +257,7 @@ class CloudscaleCommand:
 
             if not force:
                 click.confirm('Do you want to delete?', abort=True)
-            with Spinner(text=f"Deleting by UUID {uuid}"):
+            with Spinner(text=f"Deleting by {self.resource_uuid_name} {uuid}"):
                 self.get_client_resource().delete(uuid)
             click.echo(f"{uuid} deleted!")
         except Exception as e:
@@ -251,24 +267,24 @@ class CloudscaleCommand:
     def cmd_act(self, action, uuid, wait=False):
         with Spinner(text=f"Processing"):
             try:
-                with Spinner(text=f"Querying by UUID {uuid}"):
+                with Spinner(text=f"Querying by {self.resource_uuid_name} {uuid}"):
                     self.get_client_resource().get_by_uuid(uuid)
 
             except CloudscaleApiException as e:
                 results = self.cmd_get_by_name(name=uuid)
                 if not results:
                     if self.resource_name_key:
-                        msg = f"No resource found for {self.cloud_resource_name} having UUID or {self.resource_name_key}: {uuid}"
+                        msg = f"No resource found for {self.cloud_resource_name} having {self.resource_uuid_name} or {self.resource_name_key}: {uuid}"
                     else:
-                        msg = f"No resource found for {self.cloud_resource_name} having UUID: {uuid}"
+                        msg = f"No resource found for {self.cloud_resource_name} having {self.resource_uuid_name}: {uuid}"
                     click.echo(msg, err=True)
                     sys.exit(1)
 
                 if len(results) > 1:
-                    click.echo(f"Error: More than one resource found for {self.cloud_resource_name} having name: {uuid}. Please use UUID to select the resource.", err=True)
+                    click.echo(f"Error: More than one resource found for {self.cloud_resource_name} having name: {uuid}. Please use {self.resource_uuid_name} to select the resource.", err=True)
                     sys.exit(1)
 
-                # Single resource found, remember UUID
+                # Single resource found, remember identifier
                 uuid = results[0]['href'].split('/')[-1]
 
             try:
