@@ -1,4 +1,4 @@
-from cloudscale import CLOUDSCALE_API_ENDPOINT
+from cloudscale import CLOUDSCALE_API_URL
 from cloudscale_cli.cli import cli
 import responses
 import click
@@ -23,12 +23,12 @@ def test_subnet_get_all():
     uuid = "33333333-1864-4608-853a-0771b6885a3a"
     responses.add(
         responses.GET,
-        CLOUDSCALE_API_ENDPOINT + '/subnets',
+        CLOUDSCALE_API_URL + '/subnets',
         json=[SUBNET_RESP],
         status=200)
     responses.add(
         responses.GET,
-        CLOUDSCALE_API_ENDPOINT + '/subnets',
+        CLOUDSCALE_API_URL + '/subnets',
         json={},
         status=500)
 
@@ -53,12 +53,12 @@ def test_subnet_get_by_uuid():
     uuid = "33333333-1864-4608-853a-0771b6885a3a"
     responses.add(
         responses.GET,
-        CLOUDSCALE_API_ENDPOINT + '/subnets/' + uuid,
+        CLOUDSCALE_API_URL + '/subnets/' + uuid,
         json=SUBNET_RESP,
         status=200)
     responses.add(
         responses.GET,
-        CLOUDSCALE_API_ENDPOINT + '/subnets/' + uuid,
+        CLOUDSCALE_API_URL + '/subnets/' + uuid,
         json={},
         status=500)
 
@@ -91,21 +91,21 @@ def test_subnets_delete():
     uuid = "33333333-1864-4608-853a-0771b6885a3a"
     responses.add(
         responses.GET,
-        CLOUDSCALE_API_ENDPOINT + '/subnets/' + uuid,
+        CLOUDSCALE_API_URL + '/subnets/' + uuid,
         json=SUBNET_RESP,
         status=200)
     responses.add(
         responses.GET,
-        CLOUDSCALE_API_ENDPOINT + '/subnets/unknown',
+        CLOUDSCALE_API_URL + '/subnets/unknown',
         json=SUBNET_RESP,
         status=200)
     responses.add(
         responses.DELETE,
-        CLOUDSCALE_API_ENDPOINT + '/subnets/' + uuid,
+        CLOUDSCALE_API_URL + '/subnets/' + uuid,
         status=204)
     responses.add(
         responses.DELETE,
-        CLOUDSCALE_API_ENDPOINT + '/subnets/unknown',
+        CLOUDSCALE_API_URL + '/subnets/unknown',
         json={
             "detail": "Not found."
         },
@@ -144,12 +144,12 @@ def test_subnets_create():
     dns_server2 = "185.79.232.102"
     responses.add(
         responses.POST,
-        CLOUDSCALE_API_ENDPOINT + '/subnets',
+        CLOUDSCALE_API_URL + '/subnets',
         json=SUBNET_RESP,
         status=201)
     responses.add(
         responses.POST,
-        CLOUDSCALE_API_ENDPOINT + '/subnets',
+        CLOUDSCALE_API_URL + '/subnets',
         json=SUBNET_RESP,
         status=500)
 
@@ -190,17 +190,17 @@ def test_subnets_update():
     dns_server2 = "185.79.232.102"
     responses.add(
         responses.PATCH,
-        CLOUDSCALE_API_ENDPOINT + '/subnets/' + uuid,
+        CLOUDSCALE_API_URL + '/subnets/' + uuid,
         json=SUBNET_RESP,
         status=204)
     responses.add(
         responses.GET,
-        CLOUDSCALE_API_ENDPOINT + '/subnets/' + uuid,
+        CLOUDSCALE_API_URL + '/subnets/' + uuid,
         json=SUBNET_RESP,
         status=200)
     responses.add(
         responses.PATCH,
-        CLOUDSCALE_API_ENDPOINT + '/subnets/' + uuid,
+        CLOUDSCALE_API_URL + '/subnets/' + uuid,
         json={},
         status=500)
 
